github-actions[bot] wrote:

<!--PREMERGE ADVISOR COMMENT: Windows-->
# :window: Windows x64 Test Results

* 56859 tests passed
* 1785 tests skipped
* 2 tests failed

## Failed Tests
(click on a test name to see its output)

### Clang
<details>
<summary>Clang.CodeGenCUDA/cluster_dims.cu</summary>

```
Exit Code: 2

Command Output (stdout):
--
# RUN: at line 1
c:\_work\llvm-project\llvm-project\build\bin\clang.exe -cc1 -internal-isystem 
C:\_work\llvm-project\llvm-project\build\lib\clang\24\include -nostdsysteminc 
-triple amdgpu12.50-amd-amdhsa -fcuda-is-device -emit-llvm -x hip -o - 
C:\_work\llvm-project\llvm-project\clang\test\CodeGenCUDA\cluster_dims.cu | 
c:\_work\llvm-project\llvm-project\build\bin\filecheck.exe 
C:\_work\llvm-project\llvm-project\clang\test\CodeGenCUDA\cluster_dims.cu
# executed command: 'c:\_work\llvm-project\llvm-project\build\bin\clang.exe' 
-cc1 -internal-isystem 
'C:\_work\llvm-project\llvm-project\build\lib\clang\24\include' -nostdsysteminc 
-triple amdgpu12.50-amd-amdhsa -fcuda-is-device -emit-llvm -x hip -o - 
'C:\_work\llvm-project\llvm-project\clang\test\CodeGenCUDA\cluster_dims.cu'
# .---command stderr------------
# | Assertion failed: (V.isLValue() || V.isArray()) && "a lvalue ConstantExpr 
needs an lvalue APValue", file 
C:\_work\llvm-project\llvm-project\clang\lib\AST\Expr.cpp, line 335
# | PLEASE submit a bug report to https://github.com/llvm/llvm-project/issues/ 
and include the crash backtrace and dumped files.
# | Stack dump:
# | 0.  Program arguments: 
c:\\_work\\llvm-project\\llvm-project\\build\\bin\\clang.exe -cc1 
-internal-isystem 
C:\\_work\\llvm-project\\llvm-project\\build\\lib\\clang\\24\\include 
-nostdsysteminc -triple amdgpu12.50-amd-amdhsa -fcuda-is-device -emit-llvm -x 
hip -o - 
C:\\_work\\llvm-project\\llvm-project\\clang\\test\\CodeGenCUDA\\cluster_dims.cu
# | 1.  
C:\_work\llvm-project\llvm-project\clang\test\CodeGenCUDA\cluster_dims.cu:20:77:
 current parser token '{'
# | Exception Code: 0xC000001D
# |  #0 0x00007ff685dd8596 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x8c8596)
# |  #1 0x00007ffc43dfbb04 (C:\Windows\System32\ucrtbase.dll+0x7bb04)
# |  #2 0x00007ffc43dfcad1 (C:\Windows\System32\ucrtbase.dll+0x7cad1)
# |  #3 0x00007ffc43dfe4a1 (C:\Windows\System32\ucrtbase.dll+0x7e4a1)
# |  #4 0x00007ffc43dfe6e1 (C:\Windows\System32\ucrtbase.dll+0x7e6e1)
# |  #5 0x00007ff6881b47d1 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x2ca47d1)
# |  #6 0x00007ff6881b45d6 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x2ca45d6)
# |  #7 0x00007ff68b3a92e1 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x5e992e1)
# |  #8 0x00007ff68b3a8dfb 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x5e98dfb)
# |  #9 0x00007ff68b3be573 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x5eae573)
# | #10 0x00007ff68b3aab42 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x5e9ab42)
# | #11 0x00007ff68b3b2b39 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x5ea2b39)
# | #12 0x00007ff68b3b28b2 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x5ea28b2)
# | #13 0x00007ff68abe63bd 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x56d63bd)
# | #14 0x00007ff68abe0491 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x56d0491)
# | #15 0x00007ff68ac0d56a 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x56fd56a)
# | #16 0x00007ff68c625f1a 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x7115f1a)
# | #17 0x00007ff68c8e3cbe 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x73d3cbe)
# | #18 0x00007ff68c624e84 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x7114e84)
# | #19 0x00007ff68c624671 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x7114671)
# | #20 0x00007ff68c6235bc 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x71135bc)
# | #21 0x00007ff68c620fd0 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x7110fd0)
# | #22 0x00007ff68b58eb9e 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x607eb9e)
# | #23 0x00007ff68858672f 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x307672f)
# | #24 0x00007ff685f1c3c0 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0xa0c3c0)
# | #25 0x00007ff685fc6ad5 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0xab6ad5)
# | #26 0x00007ff6855184bb 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x84bb)
# | #27 0x00007ff685514050 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x4050)
# | #28 0x00007ff68551288b 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x288b)
# | #29 0x00007ff685526e35 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x16e35)
# | #30 0x00007ff68cd78890 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x7868890)
# | #31 0x00007ffc45704cb0 (C:\Windows\System32\KERNEL32.DLL+0x14cb0)
# | #32 0x00007ffc59b9edeb (C:\Windows\SYSTEM32\ntdll.dll+0x7edeb)
# `-----------------------------
# error: command failed with exit status: 0xc000001d
# executed command: 
'c:\_work\llvm-project\llvm-project\build\bin\filecheck.exe' 
'C:\_work\llvm-project\llvm-project\clang\test\CodeGenCUDA\cluster_dims.cu'
# .---command stderr------------
# | FileCheck error: '<stdin>' is empty.
# | FileCheck command line:  
c:\_work\llvm-project\llvm-project\build\bin\filecheck.exe 
C:\_work\llvm-project\llvm-project\clang\test\CodeGenCUDA\cluster_dims.cu
# `-----------------------------
# error: command failed with exit status: 2

--

```
</details>
<details>
<summary>Clang.SemaCUDA/cluster_dims.cu</summary>

```
Exit Code: 2

Command Output (stdout):
--
# RUN: at line 1
c:\_work\llvm-project\llvm-project\build\bin\clang.exe -cc1 -internal-isystem 
C:\_work\llvm-project\llvm-project\build\lib\clang\24\include -nostdsysteminc 
-triple amdgpu-amd-amdhsa -fcuda-is-device -ast-print -x hip -verify=NS,all 
C:\_work\llvm-project\llvm-project\clang\test\SemaCUDA\cluster_dims.cu
# executed command: 'c:\_work\llvm-project\llvm-project\build\bin\clang.exe' 
-cc1 -internal-isystem 
'C:\_work\llvm-project\llvm-project\build\lib\clang\24\include' -nostdsysteminc 
-triple amdgpu-amd-amdhsa -fcuda-is-device -ast-print -x hip -verify=NS,all 
'C:\_work\llvm-project\llvm-project\clang\test\SemaCUDA\cluster_dims.cu'
# .---command stdout------------
# | typedef long ptrdiff_t;
# | typedef unsigned long size_t;
# | typedef struct  {
# |     long long __clang_max_align_nonce1 
__attribute__((aligned(__alignof(long long))));
# |     long double __clang_max_align_nonce2 
__attribute__((aligned(__alignof(long double))));
# | } max_align_t;
# | struct dim3 {
# |     unsigned int x;
# |     unsigned int y;
# |     unsigned int z;
# |     __attribute__((host)) __attribute__((device)) dim3(unsigned int x, 
unsigned int y = 1, unsigned int z = 1) : x(x), y(y), z(z) {
# |     }
# | };
# | typedef struct hipStream *hipStream_t;
# | typedef enum hipError {
# | } hipError_t;
# | int hipConfigureCall(dim3 gridSize, dim3 blockSize, size_t sharedSize = 0, 
hipStream_t stream = 0);
# | extern "C" hipError_t __hipPushCallConfiguration(dim3 gridSize, dim3 
blockSize, size_t sharedSize = 0, hipStream_t stream = 0)
# | extern "C" hipError_t hipLaunchKernel(const void *func, dim3 gridDim, dim3 
blockDim, void **args, size_t sharedMem, hipStream_t stream)
# | void *operator new(unsigned long, void *p) {
# |     return p;
# | }
# | void *operator new[](unsigned long, void *p) {
# |     return p;
# | }
# | __attribute__((device)) void *operator new(unsigned long, void *p) {
# |     return p;
# | }
# | __attribute__((device)) void *operator new[](unsigned long, void *p) {
# |     return p;
# | }
# | const int constint = 4;
# | __attribute__((global)) void test_literal_3d() {
# | }
# | __attribute__((global)) void test_literal_2d() {
# | }
# | __attribute__((global)) void test_literal_1d() {
# | }
# | __attribute__((global)) void test_constant() {
# | }
# | template <int x, int y, int z> void test_template() {
# | }
# | template <int x, int y, int z> void test_template_expr() {
# | }
# | __attribute__((global)) void test_too_large_dim_0() {
# | }
# | __attribute__((global)) void test_too_large_dim_1() {
# | }
# | template <unsigned int a, unsigned int b, unsigned int c> void 
test_too_large_dim_template() {
# | }
# | template void test_too_large_dim_template<4, 4, 4>();
# | int none_const_int = 4;
# | __attribute__((global)) void test_non_constant_0() {
# | }
# | __attribute__((global)) void test_non_constant_1() {
# | }
# | __attribute__((global)) void test_non_constant_2() {
# | }
# | __attribute__((global)) void test_no_cluster() {
# | }
# | __attribute__((global)) void test_have_both() {
# | }
# | template <int ...args> void test_template_variadic_args() {
# | }
# | template <int ...args> void test_template_variadic_args_2() {
# | }
# `-----------------------------
# RUN: at line 2
c:\_work\llvm-project\llvm-project\build\bin\clang.exe -cc1 -internal-isystem 
C:\_work\llvm-project\llvm-project\build\lib\clang\24\include -nostdsysteminc 
-triple nvptx-nvidia-cuda -fcuda-is-device -ast-print -x hip -verify=NS,all 
C:\_work\llvm-project\llvm-project\clang\test\SemaCUDA\cluster_dims.cu
# executed command: 'c:\_work\llvm-project\llvm-project\build\bin\clang.exe' 
-cc1 -internal-isystem 
'C:\_work\llvm-project\llvm-project\build\lib\clang\24\include' -nostdsysteminc 
-triple nvptx-nvidia-cuda -fcuda-is-device -ast-print -x hip -verify=NS,all 
'C:\_work\llvm-project\llvm-project\clang\test\SemaCUDA\cluster_dims.cu'
# .---command stdout------------
# | typedef int ptrdiff_t;
# | typedef unsigned int size_t;
# | typedef struct  {
# |     long long __clang_max_align_nonce1 
__attribute__((aligned(__alignof(long long))));
# |     long double __clang_max_align_nonce2 
__attribute__((aligned(__alignof(long double))));
# | } max_align_t;
# | struct dim3 {
# |     unsigned int x;
# |     unsigned int y;
# |     unsigned int z;
# |     __attribute__((host)) __attribute__((device)) dim3(unsigned int x, 
unsigned int y = 1, unsigned int z = 1) : x(x), y(y), z(z) {
# |     }
# | };
# | typedef struct hipStream *hipStream_t;
# | typedef enum hipError {
# | } hipError_t;
# | int hipConfigureCall(dim3 gridSize, dim3 blockSize, size_t sharedSize = 0, 
hipStream_t stream = 0);
# | extern "C" hipError_t __hipPushCallConfiguration(dim3 gridSize, dim3 
blockSize, size_t sharedSize = 0, hipStream_t stream = 0)
# | extern "C" hipError_t hipLaunchKernel(const void *func, dim3 gridDim, dim3 
blockDim, void **args, size_t sharedMem, hipStream_t stream)
# | void *operator new(unsigned int, void *p) {
# |     return p;
# | }
# | void *operator new[](unsigned int, void *p) {
# |     return p;
# | }
# | __attribute__((device)) void *operator new(unsigned int, void *p) {
# |     return p;
# | }
# | __attribute__((device)) void *operator new[](unsigned int, void *p) {
# |     return p;
# | }
# | const int constint = 4;
# | __attribute__((global)) void test_literal_3d() {
# | }
# | __attribute__((global)) void test_literal_2d() {
# | }
# | __attribute__((global)) void test_literal_1d() {
# | }
# | __attribute__((global)) void test_constant() {
# | }
# | template <int x, int y, int z> void test_template() {
# | }
# | template <int x, int y, int z> void test_template_expr() {
# | }
# | __attribute__((global)) void test_too_large_dim_0() {
# | }
# | __attribute__((global)) void test_too_large_dim_1() {
# | }
# | template <unsigned int a, unsigned int b, unsigned int c> void 
test_too_large_dim_template() {
# | }
# | template void test_too_large_dim_template<4, 4, 4>();
# | int none_const_int = 4;
# | __attribute__((global)) void test_non_constant_0() {
# | }
# | __attribute__((global)) void test_non_constant_1() {
# | }
# | __attribute__((global)) void test_non_constant_2() {
# | }
# | __attribute__((global)) void test_no_cluster() {
# | }
# | __attribute__((global)) void test_have_both() {
# | }
# | template <int ...args> void test_template_variadic_args() {
# | }
# | template <int ...args> void test_template_variadic_args_2() {
# | }
# `-----------------------------
# RUN: at line 3
c:\_work\llvm-project\llvm-project\build\bin\clang.exe -cc1 -internal-isystem 
C:\_work\llvm-project\llvm-project\build\lib\clang\24\include -nostdsysteminc 
-triple amdgpu12.50-amd-amdhsa -fcuda-is-device -ast-print -x hip 
-verify=amd,common,all 
C:\_work\llvm-project\llvm-project\clang\test\SemaCUDA\cluster_dims.cu | 
c:\_work\llvm-project\llvm-project\build\bin\filecheck.exe 
-check-prefixes=CHECK 
C:\_work\llvm-project\llvm-project\clang\test\SemaCUDA\cluster_dims.cu
# executed command: 'c:\_work\llvm-project\llvm-project\build\bin\clang.exe' 
-cc1 -internal-isystem 
'C:\_work\llvm-project\llvm-project\build\lib\clang\24\include' -nostdsysteminc 
-triple amdgpu12.50-amd-amdhsa -fcuda-is-device -ast-print -x hip 
-verify=amd,common,all 
'C:\_work\llvm-project\llvm-project\clang\test\SemaCUDA\cluster_dims.cu'
# .---command stderr------------
# | Assertion failed: (V.isLValue() || V.isArray()) && "a lvalue ConstantExpr 
needs an lvalue APValue", file 
C:\_work\llvm-project\llvm-project\clang\lib\AST\Expr.cpp, line 335
# | PLEASE submit a bug report to https://github.com/llvm/llvm-project/issues/ 
and include the crash backtrace and dumped files.
# | Stack dump:
# | 0.  Program arguments: 
c:\\_work\\llvm-project\\llvm-project\\build\\bin\\clang.exe -cc1 
-internal-isystem 
C:\\_work\\llvm-project\\llvm-project\\build\\lib\\clang\\24\\include 
-nostdsysteminc -triple amdgpu12.50-amd-amdhsa -fcuda-is-device -ast-print -x 
hip -verify=amd,common,all 
C:\\_work\\llvm-project\\llvm-project\\clang\\test\\SemaCUDA\\cluster_dims.cu
# | 1.  
C:\_work\llvm-project\llvm-project\clang\test\SemaCUDA\cluster_dims.cu:21:77: 
current parser token '{'
# | Exception Code: 0xC000001D
# |  #0 0x00007ff685dd8596 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x8c8596)
# |  #1 0x00007ffc43dfbb04 (C:\Windows\System32\ucrtbase.dll+0x7bb04)
# |  #2 0x00007ffc43dfcad1 (C:\Windows\System32\ucrtbase.dll+0x7cad1)
# |  #3 0x00007ffc43dfe4a1 (C:\Windows\System32\ucrtbase.dll+0x7e4a1)
# |  #4 0x00007ffc43dfe6e1 (C:\Windows\System32\ucrtbase.dll+0x7e6e1)
# |  #5 0x00007ff6881b47d1 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x2ca47d1)
# |  #6 0x00007ff6881b45d6 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x2ca45d6)
# |  #7 0x00007ff68b3a92e1 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x5e992e1)
# |  #8 0x00007ff68b3a8dfb 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x5e98dfb)
# |  #9 0x00007ff68b3be573 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x5eae573)
# | #10 0x00007ff68b3aab42 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x5e9ab42)
# | #11 0x00007ff68b3b2b39 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x5ea2b39)
# | #12 0x00007ff68b3b28b2 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x5ea28b2)
# | #13 0x00007ff68abe63bd 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x56d63bd)
# | #14 0x00007ff68abe0491 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x56d0491)
# | #15 0x00007ff68ac0d56a 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x56fd56a)
# | #16 0x00007ff68c625f1a 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x7115f1a)
# | #17 0x00007ff68c8e3cbe 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x73d3cbe)
# | #18 0x00007ff68c624e84 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x7114e84)
# | #19 0x00007ff68c624671 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x7114671)
# | #20 0x00007ff68c6235bc 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x71135bc)
# | #21 0x00007ff68c620fd0 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x7110fd0)
# | #22 0x00007ff68b58eb9e 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x607eb9e)
# | #23 0x00007ff68858672f 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x307672f)
# | #24 0x00007ff685f1c3c0 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0xa0c3c0)
# | #25 0x00007ff685fc6ad5 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0xab6ad5)
# | #26 0x00007ff6855184bb 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x84bb)
# | #27 0x00007ff685514050 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x4050)
# | #28 0x00007ff68551288b 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x288b)
# | #29 0x00007ff685526e35 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x16e35)
# | #30 0x00007ff68cd78890 
(c:\_work\llvm-project\llvm-project\build\bin\clang.exe+0x7868890)
# | #31 0x00007ffc45704cb0 (C:\Windows\System32\KERNEL32.DLL+0x14cb0)
# | #32 0x00007ffc59b9edeb (C:\Windows\SYSTEM32\ntdll.dll+0x7edeb)
# `-----------------------------
# error: command failed with exit status: 0xc000001d
# executed command: 
'c:\_work\llvm-project\llvm-project\build\bin\filecheck.exe' 
-check-prefixes=CHECK 
'C:\_work\llvm-project\llvm-project\clang\test\SemaCUDA\cluster_dims.cu'
# .---command stderr------------
# | FileCheck error: '<stdin>' is empty.
# | FileCheck command line:  
c:\_work\llvm-project\llvm-project\build\bin\filecheck.exe 
-check-prefixes=CHECK 
C:\_work\llvm-project\llvm-project\clang\test\SemaCUDA\cluster_dims.cu
# `-----------------------------
# error: command failed with exit status: 2

--

```
</details>

If these failures are unrelated to your changes (for example tests are broken 
or flaky at HEAD), please open an issue at 
https://github.com/llvm/llvm-project/issues and add the `infrastructure` label.

https://github.com/llvm/llvm-project/pull/230388
_______________________________________________
cfe-commits mailing list
[email protected]
https://lists.llvm.org/cgi-bin/mailman/listinfo/cfe-commits

Reply via email to